web-top
=======

Web-top is a UNIX top-like tool to live HTTP requests and responses of any web server.
It is build using [Top Framework for Python](https://github.com/tradingstrategy-ai/top-framework).

![screenshot](https://raw.githubusercontent.com/tradingstrategy-ai/top-framework/master/docs/source/web-top/screenshot2.png)

- [Installation](https://top-framework.readthedocs.io/en/latest/web-top/installation.html)
- [Usage](https://top-framework.readthedocs.io/en/latest/web-top/usage.html)

# Features

- Easily integrate with any web server

- Display active and recently completed HTTP requests/responses

- Live top-like monitoring

- Easily locate stalled requests, as requests not making progress
  are sorted first and marked red

- IP address and country geolocation to understand who is using your web
  service


# Documentation

- [Browse documentation](https://top-framework.readthedocs.io/en/latest/web-top/index.html)

# Community 

- [Join Discord for any questions](https://tradingstrategy.ai/community)

# Social media

- [Follow on Twitter](https://twitter.com/TradingProtocol)
- [Follow on Telegram](https://t.me/trading_protocol)
- [Follow on LinkedIn](https://www.linkedin.com/company/trading-strategy/)

# License

MIT.

[Developed and maintained by Trading Strategy](https://tradingstrategy.ai).